@@ -1,6 +1,6 @@
 <?php
 
-namespace B2;
+namespace XploreBooking;
 
 class XploreBookingPlugin
 {
@@ -8,6 +8,10 @@ class XploreBookingPlugin
     private $pluginDirectoryPath;
     private $pluginDirectoryURL;
 
+    private $journeyController;
+    private $orderController;
+    private $ticketController;
+
     public function __construct($pluginDirectoryPath, $pluginDirectoryURL)
     {
         $this->pluginDirectoryPath = $pluginDirectoryPath;
@@ -17,12 +21,14 @@ class XploreBookingPlugin
         $this->registerShortCodes();
         $this->registerActions();
         $this->registerFilters();
-
+        $this->registerPostType();
     }
 
     private function setupControllers()
     {
-
+        $this->journeyController = new Controller\JourneyController();
+        $this->bookingController = new Controller\BookingController();
+        $this->ticketController = new Controller\TicketController();
     }
 
     private function registerShortCodes()
@@ -33,19 +39,13 @@ class XploreBookingPlugin
     private function registerActions()
     {
         add_action('wp_enqueue_scripts', [$this, 'enqueueAssets']);
-        add_action('wp_enqueue_scripts', [$this, 'addjquery']);
-
     }
 
     private function registerFilters()
     {
-
-    }
-
-    public function addJquery()
-    {
-        wp_deregister_script('jquery');
-        wp_enqueue_script('jquery', 'https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.min.js', [], null, true);
+        add_filter('page_template', [$this, 'assignTemplates']);
+        add_filter('acf/settings/save_json', [$this, 'acfJsonSaveLocation']);
+        add_filter('acf/settings/load_json', [$this, 'acfJsonLoadLocation']);
     }
 
     public function pluginActivation()
@@ -56,8 +56,8 @@ class XploreBookingPlugin
     private function createPages()
     {
         $pageDefinitions = [
-            'click-collect-login' => [
-                'post_title' => 'Click & Collect Login',
+            'booking' => [
+                'post_title' => 'Booking',
             ],
         ];
 
@@ -81,17 +81,14 @@ class XploreBookingPlugin
 
     public function enqueueAssets()
     {
-        //TODO: REPLACE WITH CORRECT
-        if (is_page(['click-collect-dashboard', 'click-collect-location', 'click-collect-login'])) {
-            wp_enqueue_style('click-collect-css', $this->pluginDirectoryURL . '/assets/styles/main.css', [], '1', false);
-        }
+        wp_enqueue_script('xplore-booking', $this->pluginDirectoryURL . '/dist/main.js', [], '1', true);
+        wp_enqueue_style('xplore-booking', $this->pluginDirectoryURL . '/dist/main.css', [], '1');
     }
 
-    function clickCollectTemplates($page_template)
+    function assignTemplates($page_template)
     {
-        //TODO: REPLACE WITH CORRECT
-        if (is_page(['click-collect-login', 'click-collect-location', 'click-collect-dashboard'])) {
-            $page_template = $this->pluginDirectoryPath . '/templates/template-click-collect.php';
+        if (is_page('booking')) {
+            $page_template = $this->pluginDirectoryPath . '/templates/template-xplore-booking.php';
         }
         return $page_template;
     }
@@ -111,4 +108,24 @@ class XploreBookingPlugin
         return $roles;
     }
 
-}
+    public function registerPostType()
+    {
+        Post\Journey::registerPostType();
+        Post\Booking::registerPostType();
+        Post\Ticket::registerPostType();
+    }
+
+    public function acfJsonSaveLocation()
+    {
+        $path = get_stylesheet_directory() . '/acf-json';
+        return $path;
+    }
+
+    public function acfJsonLoadLocation($paths)
+    {
+        unset($paths[0]);
+        $paths[] = get_stylesheet_directory() . '/acf-json';
+        return $paths;
+    }
+
+    }
